# Changelog

## 4.0.0 (23.05.2020)
### Added
- Support of Django 2.1
- Support of Django 2.2

### Removed
- Support of Django < 1.11
- Support of Python 2
- Support of Python 3.4

## 3.2.0 (03.05.2018)
* Support ImageField with constraints
* Update structure to have `fields` as package

## 3.1.0 (2017.12.24)
* Windows support for magic, thanks to PR #7 from @epicfaace

## 3.0.7 (2017.08.16)
* Package metadata updates
* Usage of lazy texts for translations

## 3.06 (2017.05.15)
* Close #4 (commit 982991c)
* Update messages
* Update tests (still ongoing)

## 3.0.4 (2017.05.11)
* Close #2 (commit 41ba77d)
* Update documentation
* Update tests (still ongoing)
* Integration with coveralls.io
* Fix js_checker issue in field deconstruct

## 3.0.3 (2017.04.12)
* Closes #1 (commit 1ff3fc8)
* Travis config
* Package metadata
* PyPI release

## 3.0.0 (2017.03.06)
* Update Field
  * New name
  * Drop quota
  * Add javascript file size validator
* Update tests
  * Now working with latest versions of Python and Django
  * Integration with Travis CI
